#
# spec file for package konqueror
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           konqueror
Version:        23.08.2
Release:        1.1
Summary:        KDE File Manager and Browser
# Note for legal: konqueror-17.04.2/webenginepart/autotests/webengine_testutils.h is Qt commercial OR GPL-3.0
# but it is neither built nor installed in our package.
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/konqueror
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  libtidy-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KDED)
BuildRequires:  cmake(KF5Activities)
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KDELibs4Support)
BuildRequires:  cmake(KF5KHtml)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Su)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5TextToSpeech)
BuildRequires:  cmake(Qt5WebEngine)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
Requires:       webenginepart
Recommends:     %{name}-plugins
Recommends:     dolphin-part
Obsoletes:      kde-baseapps5-libkonq < %{version}
Provides:       kde-baseapps5-libkonq = %{version}
Obsoletes:      kde-baseapps-libkonq < %{version}
Provides:       kde-baseapps-libkonq = %{version}
Obsoletes:      %{name}-libkonq < %{version}
Provides:       %{name}-libkonq = %{version}
Obsoletes:      kdebase4-libkonq
Obsoletes:      libKF5Konq6 < 17.04
Provides:       libKF5Konq6 = 17.04
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 riscv64

%description
Konqueror allows you to manage your files and browse the web in a
unified interface.

%package -n webenginepart
Summary:        KDE WebEngine web browser component

%description -n webenginepart
This package contains a HTML rendering engine for Konqueror that is based on QtWebEngine.

%package -n konqueror-plugins
Summary:        KDE File Manager and Browser
Requires:       %{name} = %{version}
Obsoletes:      fsview5 < %{version}
Provides:       fsview5 = %{version}
Obsoletes:      konqueror5-plugins < %{version}
Provides:       konqueror5-plugins = %{version}

%description -n konqueror-plugins
These plugins extend the functionality of Konqueror.

%package  devel
Summary:        KDE Konqueror Libraries: Build Environment
Requires:       %{name} = %{version}
Obsoletes:      kdebase4-devel
# FIXME 4.x variants of DBus interfaces need to go to devel package
Obsoletes:      kde-baseapps5-devel < %{version}
Provides:       kde-baseapps5-devel = %{version}
Obsoletes:      kde-baseapps-devel < %{version}
Provides:       kde-baseapps-devel = %{version}
Obsoletes:      libkonq-devel < %{version}
Provides:       libkonq-devel = %{version}

%description devel
Development package for the konqueror libraries.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name
%{kf5_find_htmldocs}

%ldconfig_scriptlets
%ldconfig_scriptlets -n konqueror-plugins

%files
%license LICENSES/*
%config %{_kf5_configdir}/autostart/konqy_preload.desktop
%{_kf5_debugdir}/konqueror.categories
%dir %{_kf5_sharedir}/konqsidebartng
%dir %{_kf5_sharedir}/konqsidebartng/entries
%dir %{_kf5_sharedir}/konqsidebartng/plugins
%dir %{_kf5_sharedir}/kcontrol
%dir %{_kf5_sharedir}/kcontrol/pics
%dir %{_kf5_sharedir}/kxmlgui5
%dir %{_kf5_plugindir}/konqueror_kcms
%doc %lang(en) %{_kf5_htmldir}/en
%{_datadir}/kcmcss/
%{_kf5_applicationsdir}/kfmclient.desktop
%{_kf5_applicationsdir}/kfmclient_dir.desktop
%{_kf5_applicationsdir}/kfmclient_html.desktop
%{_kf5_applicationsdir}/kfmclient_war.desktop
%{_kf5_applicationsdir}/konqbrowser.desktop
%{_kf5_applicationsdir}/bookmarks.desktop
%{_kf5_applicationsdir}/org.kde.konqueror.desktop
%{_kf5_appstreamdir}/org.kde.konqueror.appdata.xml
%{_kf5_bindir}/kfmclient
%{_kf5_bindir}/konqueror
%{_kf5_configkcfgdir}/konqueror.kcfg
%{_kf5_configdir}/useragenttemplatesrc
%{_kf5_datadir}/kbookmark/
%{_kf5_dbusinterfacesdir}/org.kde.Konqueror.Main.xml
%{_kf5_dbusinterfacesdir}/org.kde.Konqueror.MainWindow.xml
%{_kf5_iconsdir}/hicolor/*/*/konqueror.*
%{_kf5_libdir}/libKF5Konq.so.*
%{_kf5_libdir}/libkdeinit5_kfmclient.so
%{_kf5_libdir}/libkdeinit5_konqueror.so
%{_kf5_libdir}/libkonquerorprivate.so.*
%{_kf5_plugindir}/konqueror_kcms/kcm_bookmarks.so
%{_kf5_plugindir}/konqueror_kcms/kcm_konq.so
%{_kf5_plugindir}/konqueror_kcms/kcm_performance.so
%{_kf5_plugindir}/konqueror_kcms/khtml_appearance.so
%{_kf5_plugindir}/konqueror_kcms/khtml_behavior.so
%{_kf5_plugindir}/konqueror_kcms/khtml_cache.so
%{_kf5_plugindir}/konqueror_kcms/khtml_filter.so
%{_kf5_plugindir}/konqueror_kcms/khtml_general.so
%{_kf5_plugindir}/konqueror_kcms/khtml_java_js.so
%{_kf5_plugindir}/konqueror_kcms/khtml_useragent.so
%{_kf5_servicesdir}/org.kde.konqueror.desktop
%{_kf5_sharedir}/kconf_update/webenginepart.upd
%{_kf5_sharedir}/kcontrol/pics/onlyone.png
%{_kf5_sharedir}/kcontrol/pics/overlapping.png
%{_kf5_sharedir}/konqueror/

%files -n webenginepart
%dir %{_kf5_plugindir}/kf5/
%dir %{_kf5_plugindir}/kf5/parts/
%dir %{_kf5_sharedir}/webenginepart/
%{_kf5_iconsdir}/hicolor/*/*/webengine.*
%{_kf5_kxmlguidir}/webenginepart/
%{_kf5_libdir}/libkwebenginepart.so
%{_kf5_plugindir}/kf5/parts/webenginepart.so
%{_kf5_servicesdir}/webenginepart.desktop
%{_kf5_sharedir}/webenginepart/error.html

%files -n konqueror-plugins
%config %{_kf5_configdir}/konqsidebartngrc
%config %{_kf5_configdir}/translaterc
%dir %{_kf5_kxmlguidir}/fsview
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/parts
%dir %{_kf5_plugindir}/khtml
%dir %{_kf5_plugindir}/khtml/kpartplugins
%dir %{_kf5_plugindir}/dolphinpart
%dir %{_kf5_plugindir}/dolphinpart/kpartplugins
%dir %{_kf5_plugindir}/konqueror
%dir %{_kf5_plugindir}/konqueror/kpartplugins
%dir %{_kf5_plugindir}/kwebkitpart
%dir %{_kf5_plugindir}/kwebkitpart/kpartplugins
%dir %{_kf5_plugindir}/webenginepart
%dir %{_kf5_plugindir}/webenginepart/kpartplugins
%{_kf5_bindir}/fsview
%{_kf5_bindir}/kcreatewebarchive
%{_kf5_configkcfgdir}/kcreatewebarchive.kcfg
%{_kf5_debugdir}/akregatorplugin.categories
%{_kf5_debugdir}/fsview.categories
%{_kf5_iconsdir}/*/*/actions/babelfish.*
%{_kf5_iconsdir}/*/*/actions/imagegallery.png
%{_kf5_iconsdir}/*/*/actions/webarchiver.*
%{_kf5_iconsdir}/hicolor/*/apps/fsview.png
%{_kf5_kxmlguidir}/fsview/fsview_part.rc
%{_kf5_libdir}/libkonqsidebarplugin.so.*
%{_kf5_plugindir}/akregatorkonqfeedicon.so
%dir %{_kf5_plugindir}/kf5/kfileitemaction/
%{_kf5_plugindir}/kf5/kfileitemaction/akregatorplugin.so
%{_kf5_plugindir}/autorefresh.so
%{_kf5_plugindir}/babelfishplugin.so
%{_kf5_plugindir}/khtmlttsplugin.so
%{_kf5_plugindir}/konqueror_kcms/kcm_history.so
%{_kf5_plugindir}/kf5/parts/fsviewpart.so
%{_kf5_plugindir}/kf5/parts/konq_sidebar.so
%{_kf5_plugindir}/khtmlsettingsplugin.so
%{_kf5_plugindir}/konqsidebar_bookmarks.so
%{_kf5_plugindir}/konqsidebar_history.so
%{_kf5_plugindir}/konqsidebar_places.so
%{_kf5_plugindir}/konqsidebar_tree.so
%{_kf5_plugindir}/konqueror_kget_browser_integration.so
%{_kf5_plugindir}/uachangerplugin.so
%{_kf5_plugindir}/webarchiverplugin.so
%{_kf5_plugindir}/webarchivethumbnail.so
%{_kf5_plugindir}/dolphinpart/kpartplugins/kimgallery.so
%{_kf5_plugindir}/dolphinpart/kpartplugins/konq_shellcmdplugin.so
%{_kf5_plugindir}/dolphinpart/kpartplugins/dirfilterplugin.so
%{_kf5_plugindir}/khtml/kpartplugins/akregatorkonqfeediconkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/autorefreshkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/babelfishpluginkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/khtmlsettingspluginkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/khtmlttspluginkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/konqueror_kget_browser_integrationkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/uachangerpluginkhtml_kpartplugins.so
%{_kf5_plugindir}/khtml/kpartplugins/webarchiverpluginkhtml_kpartplugins.so
%{_kf5_plugindir}/konqueror/kpartplugins/searchbarplugin.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/akregatorkonqfeediconkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/autorefreshkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/babelfishpluginkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/khtmlsettingspluginkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/khtmlttspluginkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/konqueror_kget_browser_integrationkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/uachangerpluginkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/kwebkitpart/kpartplugins/webarchiverpluginkwebkitpart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/akregatorkonqfeediconwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/autorefreshwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/babelfishpluginwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/khtmlsettingspluginwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/khtmlttspluginwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/konqueror_kget_browser_integrationwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/uachangerpluginwebenginepart_kpartplugins.so
%{_kf5_plugindir}/webenginepart/kpartplugins/webarchiverpluginwebenginepart_kpartplugins.so
%{_kf5_servicesdir}/fsview_part.desktop
%{_kf5_servicesdir}/konq_sidebartng.desktop
%{_kf5_servicesdir}/webarchivethumbnail.desktop
%{_kf5_sharedir}/akregator/
%{_kf5_sharedir}/konqsidebartng/entries/bookmarks.desktop
%{_kf5_sharedir}/konqsidebartng/entries/fonts.desktop
%{_kf5_sharedir}/konqsidebartng/entries/history.desktop
%{_kf5_sharedir}/konqsidebartng/entries/home.desktop
%{_kf5_sharedir}/konqsidebartng/entries/places.desktop
%{_kf5_sharedir}/konqsidebartng/entries/remote.desktop
%{_kf5_sharedir}/konqsidebartng/entries/root.desktop
%{_kf5_sharedir}/konqsidebartng/entries/services.desktop
%{_kf5_sharedir}/konqsidebartng/plugins/konqsidebar_bookmarks.desktop
%{_kf5_sharedir}/konqsidebartng/plugins/konqsidebar_history.desktop
%{_kf5_sharedir}/konqsidebartng/plugins/konqsidebar_places.desktop
%{_kf5_sharedir}/konqsidebartng/plugins/konqsidebar_tree.desktop

%files devel
%{_kf5_cmakedir}/KF5Konq/
%{_kf5_libdir}/libKF5Konq.so
%{_kf5_libdir}/libkonqsidebarplugin.so
%{_kf5_includedir}/
%{_includedir}/konqsidebarplugin.h

%files lang -f %{name}.lang

%changelog
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix compiling with strict iterators
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Use correct default value
  * Add an hidden --mimetype option to kfmclient
  * Connect to the textChanged instead of the textEdited signals
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Add option to restore last window when starting Konqueror again (kde#421245)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Remove qDebug
  * Make it clearer where the user should enter the custom
    start page (kde#449874)
  * Clean up defunct opensearch classes
  * Fix loading of searchbar plugin
  * Fix search plugin not showing up in config dialog
  * Remove unnecessary include
  * Move wallet from WebEnginePage to WebEnginePart
  * Inject scripts in parts created by WebEnginePage::createWindow
  * Enable ScreenCapture attribute in WebEnginePart (kde#450386)
  * Ignore query and fragment when checking permissions
  * Port konqueror plugins to use embedded json metadata
  * Avoid having more than one certificate error dialog at the same
    time in the same window
  * Perform spellchecker setup on creation (kde#434173)
  * Fix speech getting cancelled early in ttsplugin
  * kget plugin: Define the translation domain at the CMake level
  * Add TryExec property to kget plugin
  * Import kget plugin
  * Port KPart plugins to custom KonqParts::Plugin
  * Import KParts::Plugin class in LibKonq
  * Port from KPluginSelector to KPluginWidget
  * appstream: Remove duplicated release info
  * This I18N_NOOP is not necessary here
  * Add GitLab CI
  * Avoid possible endless loops when opening URLs
  * Remove check if KCMs are authorized
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * appstream: Remove duplicated release info
* Tue Dec 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Build the TTS plugin
* Tue Dec 21 2021 Wolfgang Bauer <wbauer@tmo.at>
- Require webenginepart, it's needed for the introduction page
- Recommend konqueror-plugins for additional functionality
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Make Konqueror compatible with KIO 5.86.0 (kde#442636)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Replace handleInitError with KParts::BrowserRun::init
  * Add a comment explaining the interaction with WebEnginePart
  * Fix signature and avoid calling url() repeatedly
  * Make Konqueror compatible with KIO 5.86.0 (kde#442636)
  * Don't open HTTP URLs in another browser than Konqueror, from Konqueror
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Tell cmake our version
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Remove modules for settings kio slave
  * CMake: handle hunspell-has-no-dictionaries
  * CMake: require CMake 3.5 or later
  * Port to KXMLGUIFactory::showConfigureShortcutsDialog()
  * Move all one-time WebEnginePart initialiation in a single place
  * Web archive thumbnailer: Change one qCWarning() -> qCDebug()
  * Image Gallery: Eliminate 'endl' deprecation warnings with Qt 5.15
  * FSView: Eliminate 'endl' deprecation warnings with Qt 5.15
  * Refactor ClientApp::createNewWindow
  * Make some implicit dependencies explicit
  * Don't forward declaration when we already include file
  * Add some missing linkages
  * Restore spell checking support in HTML pages
  * Remove duplicate connection, also fixing a compilation error
  * Emit completedWithPendingAction when loading a page with http-equiv="refresh"
  * Restore adblock filter
  * kfmclient: Fix recursive invocation and handle association correctly
  * Proper history navigation
  * Display favicons for bookmarks in submenus
  * babelfish: Line break in long security warning message
  * webarchiver: Disable the "Create" button if no valid source URL
  * Show favicons in bookmarks
  * Restore saving of status bar
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * KonqCombo: Use new QComboBox signal and new-style connect
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Specify desktop-id in appdata file
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Force using WebEnginePart to open konq: URLS (kde#424848)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Repair running desktop files and executables from konqueror
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * use ecm_add_test to actuall run sidebar-modulemanagertest
  * appdata: more general doc URL
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes to list here.
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Make `konqueror` open a window even if already running. (kde#388333)
  * Fix crash due to changes in KBookmarkMenu
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Fix crash due to changes in KBookmarkMenu
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
- Dropped patches, now upstream:
  * Restore-ability-to-close-tab-by-clicking-on-close-button.patch
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Mon Dec 16 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patch to make closing a tab via its close button
  work again:
  * Restore-ability-to-close-tab-by-clicking-on-close-button.patch
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- No code change since 19.11.90
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Fix connect warning about moveTab
  * Port away from KStartupInfo::setNewStartupId deprecated API
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
- Remove obsolete version requirements
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Fix CMakeLists.txt to compile WebEnginePartHtmlEmbedder on Qt before Qt-5.12
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * [webenginepart] Fix build with cmake < 3.7
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Fix QStandardPaths usage so the sidebar entries are found
  * Add missing include
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Fix removal of cookies without a Domain field
  * Use QWebEngineDownloadItem::page() if possible
  * Register custom protocols using QWebEngineUrlScheme
  * Use the new logging category directory with ECM >= 5.59.0
  * Install in new logging directory when we use kf5 5.59.0
  * add a generic name
  * network category wanted by kde.org/applications
  * add some categories for new kde.org/applications
  * Port more deprecated methods
  * Convert deprecated methods
* Thu Jul 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use kf5_debugdir macro for specifying the logging categories location
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * fix crash in webenginepart on konqueror shutdown (kde#407454)
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Fix compilation with Qt 5.13 (QByteArray/QString confusions)
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix license
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix all plugin ui.rc/metadata to be also installed for webenginepart
  * Fix error page to have UTF-8 encoding set as needed
  * Fix ui.rc files to use non-deprecated <gui> and to match DOCTYPE
  * Fix WebEngineTextExtension::completeText a bit
  * Remove unused find_package for Qt5Xml
  * Fix KF5_MIN_VERSION to match API used by code for some releases
  * Properly support BUILD_TESTING
  * Do not duplicated work of KAboutData::setupCommandLine()
  * Use same konqueror.org homepage everywhere
  * Remove duplicated cmake_minimum_required from libkonq, was resetting things
  * Remove usage of dead QT_USE_FAST_CONCATENATION
  * Remove unneeded moc includes
  * Use more https in links
  * Fix typo in include directory
  * Fix broken-by-kf5-port installation of some icons
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * actually initialize kcrash properly
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Fix build with Qt 5.12
  * Add donation url to appdata
  * Ask the user what to do in case of a SSL certificate error
  * Fix handling of cookies without a domain
  * File Size View: Fix KProtocolInfoFactory assert
  * Fix removing cookies from KCookieServer
  * use QIcon::fromTheme() instead of QIcon()
  * Add basic tests for WebEnginePartCookieJar
  * Fix minor EBN issues and minor porting
  * Fix compilation
  * Fix minor EBN issues [includes]
  * Replace KStatusBar with QStatusBar
  * Remove KIcon from plugins
  * Remove call to hasSubUrl
  * Remove KUrl from autorefresh, dirfilter, domtreeview and fsview plugins
  * Fix minor EBN issues
  * Fix the workaround for cookie expiration date in WebEnginePart
  * Don't define WebEnginePartCookieJar::filterCookie for old versions of Qt
  * Synchronize cookies between QWebEngine and KCookieServer
  * Fix issue with info protocol and refresh
  * Restore ability to view help pages from Konqueror
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Sat Jul 28 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, it doesn't compile with 4.8 anymore
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Restore the ability to view man and info pages from Konqueror
  * Display an error page for error URLs in WebEnginePart
  * Do not duplicate work of KAboutData::setupCommandLine()
  * Akregator feed detector plugin: Use new connect() syntax
  * Akregator feed detector plugin: Make PluginBase just a namespace
  * Akregator feed detector plugin: Restore the popup menu action
  * Akregator feed detector plugin: Port away from KDELibs4Support
  * Akregator feed detector plugin: Do not crash for an invalid URL
  * Fix test failure once D12206 lands
  * Fix test failure when D11569 lands
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Load translation catalog webenginepart
  * Include zlib also on build time
  * Add back KWallet support to Konqueror
  * Fix i18n usage
- Dropped patches, now upstream:
  * add-kwallet-support-to-webengine.patch
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Sat Mar  3 2018 wbauer@tmo.at
- Add add-kwallet-support-to-webengine.patch to allow storing user
  names and passwords in kwallet when using the webenginepart
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Sat Jan 20 2018 wbauer@tmo.at
- Fix package summary and description
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Give a name to the menus in the webenginepart (kde#386714)
  * New maintainer for Konqueror: Stefano Crocco
  * Repair konqviewmgrtest by disabling creation of preloaded windows.
  * Bundle the ui.rc file into a qrc resource.
  * Fix download behavior when using webengine part
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Sun Oct 29 2017 fabian@ritter-vogt.de
- Don't try to install Home.desktop in /usr/share/applications,
  the copy from plasma5-workspace (by kio_desktop) should be used
  instead (boo#1058743)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Fri Jul  7 2017 wbauer@tmo.at
- Recommend dolphin-part to make file management work out of the
  box (boo#1047665)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix build with Qt 5.9 (kde#377490)
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Port kde4_add_app_icon to ecm_add_app_icon
  * Save/restore window size
  * Accept single line command options like we used to do
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * rename define, to match kdepim
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Tue Dec 13 2016 wbauer@tmo.at
- Recommend kwebkitpart again instead of webenginepart for now, the
  latter crashes currently with Qt 5.7.1 (same reason as
  QTCREATORBUG-17296) and still lacks some KDE integration (e.g.
  storing passwords in kwallet, kde#372777)
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Sun Nov 27 2016 tittiatcoke@gmail.com
- Update spec-files to be consistent wiht KA
